COMPMID-3221: (DATA_UPDATE) add graph example for EDSR

Change-Id: Id74190e2af444da8dab4813fd65016104f3882a9
Signed-off-by: Sang-Hoon Park <sang-hoon.park@arm.com>
Reviewed-on: https://review.mlplatform.org/c/ml/ComputeLibrary/+/2862
Tested-by: Arm Jenkins <bsgcomp@arm.com>
Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com>
Comments-Addressed: Arm Jenkins <bsgcomp@arm.com>
diff --git a/arm_compute/graph/nodes/DeconvolutionLayerNode.h b/arm_compute/graph/nodes/DeconvolutionLayerNode.h
index 09601ab..5633898 100644
--- a/arm_compute/graph/nodes/DeconvolutionLayerNode.h
+++ b/arm_compute/graph/nodes/DeconvolutionLayerNode.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2019 ARM Limited.
+ * Copyright (c) 2018-2020 ARM Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -36,9 +36,10 @@
 public:
     /** Constructor
      *
      * @param[in] info DeConvolution layer attributes
      */
-    DeconvolutionLayerNode(PadStrideInfo info);
+    DeconvolutionLayerNode(PadStrideInfo info, QuantizationInfo out_quant_info = QuantizationInfo());
     /** Deconvolution metadata accessor
      *
      * @return Deconvolution information
@@ -63,7 +64,8 @@
     void accept(INodeVisitor &v) override;
 
 private:
-    PadStrideInfo _info;
+    PadStrideInfo    _info;
+    QuantizationInfo _out_quant_info;
 };
 } // namespace graph
 } // namespace arm_compute
@@ -36,9 +36,10 @@
     /** Constructor
      *
-     * @param[in] info DeConvolution layer attributes
+     * @param[in] info           DeConvolution layer attributes
+     * @param[in] out_quant_info (Optional) Output quantization infomation
      */